==> haskell-base-orphans-0.8-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-base-orphans.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-orphans
version: 0.8
id: base-orphans-0.8-3LZD8XuPCa03QSRrjkQtJI
key: base-orphans-0.8-3LZD8XuPCa03QSRrjkQtJI
license: MIT
copyright: (c) 2012-2017 Simon Hengel,
           (c) 2014-2017 João Cristóvão,
           (c) 2015-2017 Ryan Scott
maintainer: Simon Hengel <sol@typeful.net>,
            João Cristóvão <jmacristovao@gmail.com>,
            Ryan Scott <ryan.gl.scott@gmail.com>
author: Simon Hengel <sol@typeful.net>,
        João Cristóvão <jmacristovao@gmail.com>,
        Ryan Scott <ryan.gl.scott@gmail.com>
homepage: https://github.com/haskell-compat/base-orphans#readme
synopsis: Backwards-compatible orphan instances for base
description:
    @base-orphans@ defines orphan instances that mimic instances available in later versions of @base@ to a wider (older) range of compilers. @base-orphans@ does not export anything except the orphan instances themselves and complements @<http://hackage.haskell.org/package/base-compat base-compat>@.
    See the README for what instances are covered: <https://github.com/haskell-compat/base-orphans#readme>. See also the <https://github.com/haskell-compat/base-orphans#what-is-not-covered what is not covered> section.
category: Compatibility
abi: e17da400f42f5b3da9a563b061288921
exposed: True
exposed-modules:
    Data.Orphans
hidden-modules: Data.Orphans.Prelude
import-dirs: /usr/lib/ghc-8.4.3/site-local/base-orphans-0.8
library-dirs: /usr/lib/ghc-8.4.3/site-local/base-orphans-0.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/base-orphans-0.8
hs-libraries: HSbase-orphans-0.8-3LZD8XuPCa03QSRrjkQtJI
depends:
    base-4.11.1.0 ghc-prim-0.5.2.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
haddock-interfaces: /usr/share/doc/haskell-base-orphans/html/base-orphans.haddock
haddock-html: /usr/share/doc/haskell-base-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base-orphans-0.8-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-base-orphans.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-orphans
version: 0.8
id: base-orphans-0.8-4huH01MmiV449ptUKInvC8
key: base-orphans-0.8-4huH01MmiV449ptUKInvC8
license: MIT
copyright: (c) 2012-2017 Simon Hengel,
           (c) 2014-2017 João Cristóvão,
           (c) 2015-2017 Ryan Scott
maintainer: Simon Hengel <sol@typeful.net>,
            João Cristóvão <jmacristovao@gmail.com>,
            Ryan Scott <ryan.gl.scott@gmail.com>
author: Simon Hengel <sol@typeful.net>,
        João Cristóvão <jmacristovao@gmail.com>,
        Ryan Scott <ryan.gl.scott@gmail.com>
homepage: https://github.com/haskell-compat/base-orphans#readme
synopsis: Backwards-compatible orphan instances for base
description:
    @base-orphans@ defines orphan instances that mimic instances available in later versions of @base@ to a wider (older) range of compilers. @base-orphans@ does not export anything except the orphan instances themselves and complements @<http://hackage.haskell.org/package/base-compat base-compat>@.
    See the README for what instances are covered: <https://github.com/haskell-compat/base-orphans#readme>. See also the <https://github.com/haskell-compat/base-orphans#what-is-not-covered what is not covered> section.
category: Compatibility
abi: e9fa092af04cd58ebcb8cdf33f10dac9
exposed: True
exposed-modules:
    Data.Orphans
hidden-modules: Data.Orphans.Prelude
import-dirs: /usr/lib/ghc-8.4.3/site-local/base-orphans-0.8
library-dirs: /usr/lib/ghc-8.4.3/site-local/base-orphans-0.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/base-orphans-0.8
hs-libraries: HSbase-orphans-0.8-4huH01MmiV449ptUKInvC8
depends:
    base-4.11.1.0 ghc-prim-0.5.2.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
haddock-interfaces: /usr/share/doc/haskell-base-orphans/html/base-orphans.haddock
haddock-html: /usr/share/doc/haskell-base-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
